@@ -51,7 +51,7 @@ function(data,cl,n.cat,same.ncat=FALSE,compPval=TRUE){
 	if(!compPval)
 		return(stats)
 	df<-(df-1)*(n.lev-1)
-	rawp<-pchisq(stats,df,lower=FALSE)
+	rawp<-pchisq(stats,df,lower.tail=FALSE)
 	rawp[df==0] <- 1
 	structure(list(stats=stats,df=df,rawp=rawp))
 }
